#
# spec file for package python-sidpy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define packagename sidpy
Name:           python-sidpy
Version:        0.12.3
Release:        1.1
Summary:        Utilities for processing Spectroscopic and Imaging Data
License:        MIT
URL:            https://pycroscopy.github.io/sidpy/
Source:         https://github.com/pycroscopy/sidpy/archive/%{version}.tar.gz#/%{packagename}-%{version}.tar.gz
Source99:       python-sidpy.rpmlintrc
BuildRequires:  %{python_module ase}
BuildRequires:  %{python_module cytoolz}
BuildRequires:  %{python_module dask >= 0.10}
BuildRequires:  %{python_module dask-array >= 0.10}
BuildRequires:  %{python_module distributed >= 2}
BuildRequires:  %{python_module h5py >= 2.6.0}
BuildRequires:  %{python_module ipywidgets >= 5.2.2}
BuildRequires:  %{python_module joblib >= 0.11.0}
BuildRequires:  %{python_module matplotlib >= 2.0.0}
BuildRequires:  %{python_module mpi4py}
BuildRequires:  %{python_module numpy >= 1.10}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module scikit-learn}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module toolz}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ase
Requires:       python-cytoolz
Requires:       python-dask >= 0.10
Requires:       python-dask-array >= 0.10
Requires:       python-distributed >= 2
Requires:       python-h5py >= 2.6.0
Requires:       python-ipython >= 6
Requires:       python-ipywidgets >= 5.2.2
Requires:       python-joblib >= 0.11.0
Requires:       python-matplotlib >= 2.0.0
Requires:       python-numpy >= 1.10
Requires:       python-psutil
Requires:       python-scikit-learn
Requires:       python-scipy
Requires:       python-toolz
Recommends:     python-mpi4py
Recommends:     python-qt5
BuildArch:      noarch
%python_subpackages

%description
Python utilities for storing, visualizing, and processing Spectroscopic and Imaging Data (SID).

%prep
%setup -q -n %{packagename}-%{version}
# https://github.com/pycroscopy/sidpy/issues/142
sed -i -e /pytest-runner/d -e /six/d setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Broken test
donttest="test_standard_serial_compute_few_jobs"
%pytest -k "not $donttest"

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/%{packagename}-%{version}*-info
%{python_sitelib}/%{packagename}

%changelog
* Sun Jan 21 2024 Dirk Müller <dmueller@suse.com>
- update to 0.12.3:
  * Variance included by Boris
  * Visualizer updated to include variance  by Boris
  * Visualizer updated to make it flexible by Gerd
  * Tests updated by Boris
  * get_spectrum_dims is renamed to get spectral_dims
- update to 0.12.1:
  * updates to some of the visualizers (spectrum visualizer for
    example)
  * bug fix to Sidpy Fitter class that was preventing proper
    scaling with multiple workers
  * changes on the backend regarding getting and setting
    dimensions
  * additional tests
- update to 0.12.0:
  * New version of sidpy has been released. The major change is
    that previous operations that would have resulted in return
    of numpy or dask arrays are now programmed to return sidpy
    dataset objects. This is particularly useful for instance
    when wishing to crop, slice, and perform standard arithmetic
    operations on sidpy datasets. The sidpy.fitter class has been
    updated to allow for complex datasets. An example notebook is
    provided here
* Mon Mar 27 2023 Ben Greiner <code@bnavigator.de>
- Reenable python311 with dask
- Fix requirements
- PEP517
* Mon Mar 27 2023 Daniel Garcia <daniel.garcia@suse.com>
- Disable python3.11 build, python-dask dependency doesn't support
  python3.11 yet.
* Wed Feb  8 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.11.2
  * compatibility to numpy >1.24
- 0.11.1
  * Minor release. Small fixes to image windowing, four dimensional visualizer,
    and adding of a structure attribute to the sidpy.dataset object.
- 0.11
  * Added CHANNEL dimension type for sidpy dimensions (for example of usage see
    this link) . This is useful for multi-channel spectral datasets, which can
    now be plotted using the intrinsic .plot() method
  * Added updated capability on spectral visualizer to enable plotting of
    multi-channel spectra
  * Small changes with set_dimension() method to be more robust
  * Minor bug fixes
  * Updates to various tests
- 0.10
  * This release adds a few 'under the hood' changes to the sidpy dataset
    object, with respect to chunking and folding/unfolding. Some minor edits to
    some visualization functions were also made. A new method
    visualize_fit_results() to the SidFitter class was added to aid in
    visualization of functional fits.
- 0.0.9
  * Added fitter class and improved tests.
* Fri Oct 21 2022 pgajdos@suse.com
- python-six is not required
* Tue Apr 26 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove skip for Python 3.10, dask is now available.
* Sun Feb  6 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.0.8
  * Support of thumbnails for icon view of directory
  * updated for new version of ipyfilechooser
  * better support of dask functions (thanks Mani).
  * nested dictionaries are now written and read from hdf5 files
  * support of 4D image sets in plotting.
  * Minor bug fixes
* Sat Feb  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Skip build for python 3.10: python-dask is not (yet) compatible.
* Tue Dec 14 2021 pgajdos@suse.com
- pytest-runner is not required for build
* Wed Apr 14 2021 andy great <andythe_great@pm.me>
- Update to version 0.0.5.
  * Mathematical operations return sidpy.Dataset now instead of
    dask.array.
* Mon Jan 18 2021 andy great <andythe_great@pm.me>
- Disable build for python 2 and python3.6 because numpy and scipy
  don't support them.
* Mon Dec 21 2020 andy great <andythe_great@pm.me>
- Update to version 0.0.4a.
  * range of bug fixes
  * greatly expanded tests
  * added ore docstrings
  * simplified imports and removed unnecessary functions
  * compatibility with single core machines
  * changes to write_simple_attrs method, to now include ability to write enum objects
  * changes to minimum dimension size
* Mon Nov 23 2020 andy great <andythe_great@pm.me>
- Update to version 0.0.3.
  * sidpy.Dataset extend dask.array
  * sidpy.Dimension extends numpy.ndarray
  * Improved unit testing for core functions
* Fri Sep 18 2020 andy great <andythe_great@pm.me>
- Remove fix_tests_dir_in_site_package.patch, fix in sidpy 0.0.2.
- Update to version 0.0.2.
  * Submodules of the main modules can be imported directly.
    E.g. import sidpy.hdf_utils instead of sidpy.hdf.hdf_utils
  * Preventing tests from being deployed into site-packages
  * Fixed bugs in sidpy.io.interface_utils.py that was causing
    problems when importing sidpy
  * Added python 3.8 support and testing
  * Improvements and bug fixes to dataset.py
  * Added plotting utilities written to support upcoming
    Dataset.plot().
  * Ported additional hdf_utils functions for copying datasets
    (now in hdf_utils) and provenance tracking within HDF files
    (now in prov_utils)
  * Added Reader class to do half the job of the existing
    Translator class
  * Translator class now shows a deprecation warning prompting
    users to start using Reader instead and populate ScopeReaders
* Fri Aug 14 2020 andy great <andythe_great@pm.me>
- Initial package release.
